@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.install.stubs;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.plugins.install.stubs;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,12 +16,10 @@ package org.apache.maven.plugins.install.stubs;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.install.stubs;
 
-public class AttachedArtifactStub1
-    extends AttachedArtifactStub0
-{
-    public String getArtifactId()
-    {
+public class AttachedArtifactStub1 extends AttachedArtifactStub0 {
+    public String getArtifactId() {
         return "attached-artifact-test-1";
     }
 }
